"""Module containing the command builder."""
import subprocess
from typing import List


class BColors:
    """ANSI escape sequences."""

    SUCCEEDED = "\033[92m"
    WARNING = "\033[93m"
    FAILED = "\033[91m"
    END = "\033[0m"


class CommandBuilder:
    """Command Builder"""

    def __init__(self):
        self.commands = {}

    def add(self, name: str, command: List[str]):
        """Adds a command to the pipeline."""

        self.commands[name] = {"command": command}

    def _print_summary(self):
        """Print returncode commands."""

        print("_" * 30 + "summary" + "_" * 30)

        for name, command in self.commands.items():
            if command["returncode"] != 0:
                print(BColors.FAILED + f"ERROR: {name}: commands failed" + BColors.END)
            else:
                print(BColors.SUCCEEDED + f"{name}: commands succeeded" + BColors.END)

    @staticmethod
    def _run_command(command: List[str]):
        """Run a command."""

        run = subprocess.run(command, check=False, shell=False)
        return run.returncode

    def run(self, summary: bool = True):
        """Run commands and print summary."""

        for command in self.commands.values():
            command["returncode"] = self._run_command(command["command"])

        if summary:
            self._print_summary()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['command_builder']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['pipeline = ci_pipeline:main']}

setup_kwargs = {
    'name': 'command-builder',
    'version': '0.1.1',
    'description': 'Summary shell commands execution',
    'long_description': '# Command Builder\n\nCommand Builder is a library that manages the execution of shell commands, creating a summary of the executions. The objective is to facilitate the perception of errors.\n\n## Installation\n\n> You need Python 3.7 or above.\n\nFrom the terminal, enter:\n\n```bash\npip install command-builder\n```\n\n## Getting started\n\n> The examples refer to the newest version (0.1.0) of command-builder.\n\nFirst, let\'s init the command-builder:\n\n```python\nfrom command_builder.command_builder import CommandBuilder\n\ncommand_builder = CommandBuilder()\n\n```\n\nAdding commands:\n\n```python\ncommand_builder.add(name="ls", command=["ls", "-a"])\ncommand_builder.add(name="pwd", command=["pwd", "-o"])\n```\n\nRunning commands:\n\n```python\ncommand_builder.run()\n```\n\nOutput:\n\n```diff\n______________________________summary______________________________\n+ ls: commands succeeded\n- ERROR: pwd: commands failed\n```\n\n',
    'author': 'Guilherme Righetto',
    'author_email': 'guilhermerighetto02@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
